OC.L10N.register(
    "core",
    {
    "Please select a file." : "Seleziona un file.",
    "File is too big" : "Il file è troppo grande",
    "The selected file is not an image." : "Il file selezionato non è un'immagine.",
    "The selected file cannot be read." : "Il file selezionato non può essere letto.",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è stato caricato solo parzialmente",
    "No file was uploaded" : "Nessun file caricato",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "Invalid file provided" : "File fornito non valido ",
    "No image or file provided" : "Non è stata fornita alcun immagine o file",
    "Unknown filetype" : "Tipo di file sconosciuto",
    "An error occurred. Please contact your admin." : "Si è verificato un errore. Contatta il tuo amministratore.",
    "Invalid image" : "Immagine non valida",
    "No temporary profile picture available, try again" : "Nessuna immagine di profilo provvisoria disponibile, riprova",
    "No crop data provided" : "Non sono stati forniti dati di ritaglio",
    "No valid crop data provided" : "Non sono stati forniti dati di ritaglio validi",
    "Crop is not square" : "Il ritaglio non è quadrato",
    "State token does not match" : "Il token di stato non corrisponde",
    "Invalid app password" : "Password dell'applicazione non valida",
    "Could not complete login" : "Impossibile completare l'accesso",
    "State token missing" : "Token di stato mancante",
    "Your login token is invalid or has expired" : "Il tuo token di accesso non è valido o è scaduto",
    "Please use original client" : "Si prega di utilizzare il client originale",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Questa versione della comunità di Nextcloud non è supportata e le notifiche push sono limitate.",
    "Login" : "Accedi",
    "Unsupported email length (>255)" : "Lunghezza email non supportata (>255)",
    "Password reset is disabled" : "Ripristino password disabilitato",
    "Could not reset password because the token is expired" : "Impossibile reimpostare la password poiché il token è scaduto",
    "Could not reset password because the token is invalid" : "Impossibile reimpostare la password poiché il token non è valido",
    "Password is too long. Maximum allowed length is 469 characters." : "La password è troppo lunga. La lunghezza massima consentita è di 469 caratteri.",
    "%s password reset" : "Ripristino password di %s",
    "Password reset" : "Ripristino password",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Fai clic sul pulsante seguente per reimpostare la tua password. Se non hai richiesto la reimpostazione della password, ignora questo messaggio.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Fai clic sul collegamento seguente per reimpostare la tua password. Se non hai richiesto la reimpostazione della password, ignora questo messaggio.",
    "Reset your password" : "Ripristina la password",
    "The given provider is not available" : "Il fornitore scelto non è disponibile",
    "Task not found" : "Attività non trovata",
    "Internal error" : "Errore interno",
    "Not found" : "Non trovato",
    "Node is locked" : "Il nodo è bloccato",
    "Bad request" : "Richiesta errata",
    "Requested task type does not exist" : "Il tipo di attività richiesto non esiste",
    "Necessary language model provider is not available" : "Il necessario provider di modello per la lingua non è disponibile",
    "No text to image provider is available" : "Nessun fornitore da-testo-a-immagine disponibile",
    "Image not found" : "Immagine non trovata",
    "No translation provider available" : "Nessun fornitore di traduzioni disponibile",
    "Could not detect language" : "Impossibile rilevare la lingua",
    "Unable to translate" : "Impossibile tradurre",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Fase di riparazione:",
    "Repair info:" : "Informazioni di riparazione:",
    "Repair warning:" : "Avviso di riparazione",
    "Repair error:" : "Errore di riparazione:",
    "Nextcloud Server" : "Server Nextcloud",
    "Some of your link shares have been removed" : "Alcune delle tue condivisioni tramite collegamento sono state rimosse",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa di un bug di sicurezza abbiamo rimosso alcune delle tue condivisioni tramite collegamento. Vedi il collegamento per ulteriori informazioni.",
    "The account limit of this instance is reached." : "Il limite di utenti di questa istanza è stato raggiunto.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Inserisci la tua chiave di abbonamento nell'applicazione di supporto per aumentare il limite di utenti. In questo modo otterrai anche tutti i vantaggi aggiuntivi che Nextcloud Enterprise offre ed è altamente consigliato per l'operatività nelle aziende.",
    "Learn more ↗" : "Ulteriori informazioni ↗",
    "Preparing update" : "Preparazione dell'aggiornamento",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Utilizza lo strumento da riga di comando poiché l'aggiornamento da browser è disabilitato nel file config.php.",
    "Turned on maintenance mode" : "Modalità di manutenzione attivata",
    "Turned off maintenance mode" : "Modalità di manutenzione disattivata",
    "Maintenance mode is kept active" : "La modalità di manutenzione è lasciata attiva",
    "Updating database schema" : "Aggiornamento schema database",
    "Updated database" : "Database aggiornato",
    "Update app \"%s\" from App Store" : "Aggiorna l'applicazione \"%s\" dal negozio delle applicazioni",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controllo che lo schema del database di %s possa essere aggiornato (ciò potrebbe richiedere molto tempo in base alla dimensione del database)",
    "Updated \"%1$s\" to %2$s" : "Aggiornato \"%1$s\" a %2$s",
    "Set log level to debug" : "Imposta il livello del log per il debug",
    "Reset log level" : "Ripristina il livello del log",
    "Starting code integrity check" : "Avvio del controllo di integrità del codice",
    "Finished code integrity check" : "Controllo di integrità del codice terminato",
    "%s (incompatible)" : "%s (incompatibile)",
    "The following apps have been disabled: %s" : "Le seguenti applicazioni sono state disabilitate: %s",
    "Already up to date" : "Già aggiornato",
    "Windows Command Script" : "Script dei comandi di Windows",
    "Electronic book document" : "Documento libro elettronico",
    "TrueType Font Collection" : "Raccolta di font TrueType",
    "Web Open Font Format" : "Formato Web Open Font",
    "GPX geographic data" : "Dati geografici GPX",
    "Gzip archive" : "Archivio Gzip",
    "Adobe Illustrator document" : "Documento di Adobe Illustrator",
    "Java source code" : "Codice sorgente Java",
    "JavaScript source code" : "Codice sorgente JavaScript",
    "JSON document" : "Documento JSON",
    "Microsoft Access database" : "Database di Microsoft Access",
    "Microsoft OneNote document" : "Documento di Microsoft OneNote",
    "Microsoft Word document" : "Documento di Microsoft Word",
    "Unknown" : "Sconosciuto",
    "PDF document" : "Documento PDF",
    "PostScript document" : "Documento PostScript",
    "RSS summary" : "Riepilogo RSS",
    "Android package" : "Pacchetto Android",
    "KML geographic data" : "Dati geografici KML",
    "KML geographic compressed data" : "Dati geografici compressi KML",
    "Lotus Word Pro document" : "Documento Lotus Word Pro",
    "Excel spreadsheet" : "Foglio di calcolo Excel",
    "Excel add-in" : "Componente aggiuntivo di Excel",
    "Excel 2007 binary spreadsheet" : "Foglio di calcolo binario di Excel 2007",
    "Excel spreadsheet template" : "Modello di foglio di calcolo Excel",
    "Outlook Message" : "Messaggio di Outlook",
    "PowerPoint presentation" : "Presentazione PowerPoint",
    "PowerPoint add-in" : "Componente aggiuntivo di PowerPoint",
    "PowerPoint presentation template" : "Modello di presentazione di PowerPoint",
    "Word document" : "Documento Word",
    "ODF formula" : "Formula ODF",
    "ODG drawing" : "Disegno ODG",
    "ODG drawing (Flat XML)" : "Disegno ODG (XML piatto)",
    "ODG template" : "Modello ODG",
    "ODP presentation" : "Presentazione ODP",
    "ODP presentation (Flat XML)" : "Presentazione ODP (XML piatto)",
    "ODP template" : "Modello ODP",
    "ODS spreadsheet" : "Foglio di calcolo ODS",
    "ODS spreadsheet (Flat XML)" : "Foglio di calcolo ODS (XML piatto)",
    "ODS template" : "Modello ODS",
    "ODT document" : "Documento ODT",
    "ODT document (Flat XML)" : "Documento ODT (XML piatto)",
    "ODT template" : "Modello ODT",
    "PowerPoint 2007 presentation" : "Presentazione PowerPoint 2007",
    "PowerPoint 2007 show" : "Visualizzatore di PowerPoint 2007",
    "PowerPoint 2007 presentation template" : "Modello di presentazione di PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Foglio di calcolo Excel 2007",
    "Excel 2007 spreadsheet template" : "Modello di foglio di calcolo di Excel 2007",
    "Word 2007 document" : "Documento di Word 2007",
    "Word 2007 document template" : "Modello di documento Word 2007",
    "Microsoft Visio document" : "Documento di Microsoft Visio",
    "WordPerfect document" : "Documento WordPerfect",
    "7-zip archive" : "Archivio 7-zip",
    "Blender scene" : "Scena di Blender",
    "Bzip2 archive" : "Archivio Bzip2",
    "Debian package" : "Pacchetto Debian",
    "FictionBook document" : "Documento FictionBook",
    "Unknown font" : "Font sconosciuto",
    "Krita document" : "Documento Krita",
    "Mobipocket e-book" : "E-book Mobipocket",
    "Windows Installer package" : "Pacchetto di installazione di Windows",
    "Perl script" : "Script Perl",
    "PHP script" : "Script PHP",
    "Tar archive" : "Archivio Tar",
    "XML document" : "Documento XML",
    "YAML document" : "Documento YAML",
    "Zip archive" : "Archivio zip",
    "Zstandard archive" : "Archivio Zstandard",
    "AAC audio" : "Audio AAC",
    "FLAC audio" : "Audio FLAC",
    "MPEG-4 audio" : "Audio MPEG-4",
    "MP3 audio" : "Audio MP3",
    "Ogg audio" : "Audio Ogg",
    "RIFF/WAVe standard Audio" : "Standard audio RIFF/WAVe",
    "WebM audio" : "Audio WebM",
    "MP3 ShoutCast playlist" : "Playlist MP3 ShoutCast",
    "Windows BMP image" : "Immagine BMP di Windows",
    "Better Portable Graphics image" : "Migliore immagine grafica portatile",
    "EMF image" : "Immagine EMF",
    "GIF image" : "Immagine GIF",
    "HEIC image" : "Immagine HEIC",
    "HEIF image" : "Immagine HEIF",
    "JPEG-2000 JP2 image" : "Immagine JPEG-2000 JP2",
    "JPEG image" : "Immagine JPEG",
    "PNG image" : "Immagine PNG",
    "SVG image" : "Immagine SVG",
    "Truevision Targa image" : "Immagine Truevision Targa",
    "TIFF image" : "Immagine TIFF",
    "WebP image" : "Immagine WebP",
    "Digital raw image" : "Immagine digitale raw",
    "Windows Icon" : "Icona di Windows",
    "Email message" : "messaggio di posta elettronica",
    "VCS/ICS calendar" : "Calendario VCS/ICS",
    "CSS stylesheet" : "Foglio di stile CSS",
    "CSV document" : "Documento CSV",
    "HTML document" : "Documento HTML",
    "Markdown document" : "Documento Markdown",
    "Org-mode file" : "File Org-mode",
    "Plain text document" : "Documento di testo normale",
    "Rich Text document" : "Documento Rich Text",
    "Electronic business card" : "Biglietto da visita elettronico",
    "C++ source code" : "Codice sorgente C++",
    "LDIF address book" : "Rubrica LDIF",
    "NFO document" : "Documento NFO",
    "PHP source" : "Sorgente PHP",
    "Python script" : "Script Python",
    "ReStructuredText document" : "Documento ReStructuredText",
    "3GPP multimedia file" : "File multimediale 3GPP",
    "MPEG video" : "Video MPEG",
    "DV video" : "Video DV",
    "MPEG-2 transport stream" : "Flusso di trasporto MPEG-2",
    "MPEG-4 video" : "Video MPEG-4",
    "Ogg video" : "Video Ogg",
    "QuickTime video" : "Video QuickTime",
    "WebM video" : "Video WebM",
    "Flash video" : "Video flash",
    "Matroska video" : "Video Matroska",
    "Windows Media video" : "Video di Windows Media",
    "AVI video" : "Video AVI",
    "unknown text" : "testo sconosciuto",
    "Hello world!" : "Ciao mondo!",
    "sunny" : "soleggiato",
    "Hello {name}, the weather is {weather}" : "Ciao {name}, il tempo è {weather}",
    "Hello {name}" : "Ciao {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Questi sono i tuoi risultati di ricerca<script>alert(1)</script></strong>",
    "new" : "nuovo",
    "_download %n file_::_download %n files_" : ["scarica %n file","scarica %n file","scarica %n file"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'aggiornamento è in corso, l'abbandono di questa pagina potrebbe interrompere il processo in alcuni ambienti.",
    "Update to {version}" : "Aggiorna a {version}",
    "An error occurred." : "Si è verificato un errore.",
    "Please reload the page." : "Ricarica la pagina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'aggiornamento non è riuscito. Per ulteriori informazioni <a href=\"{url}\">controlla l'articolo del nostro forum</a> che riguarda questo problema.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'aggiornamento non è riuscito. Segnala il problema alla <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunità di Nextcloud </a>.",
    "Continue to {productName}" : "Continua in {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} in %n secondo.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi."],
    "Applications menu" : "Menu applicazioni",
    "Apps" : "Applicazioni",
    "More apps" : "Altre applicazioni",
    "_{count} notification_::_{count} notifications_" : ["{count} notifica","{count} notifiche","{count} notifiche"],
    "No" : "No",
    "Yes" : "Sì",
    "The remote URL must include the user." : "L'URL remoto deve includere l'utente.",
    "Invalid remote URL." : "URL remoto non valido.",
    "Failed to add the public link to your Nextcloud" : "Aggiunta del collegamento pubblico al tuo Nextcloud non riuscita",
    "Federated user" : "Utente federato",
    "user@your-nextcloud.org" : "utente@il-tuo-nextcloud.org",
    "Create share" : "Crea condivisione",
    "Direct link copied" : "Link diretto copiato",
    "Please copy the link manually:" : "Copia il collegamento manualmente:",
    "Custom date range" : "Intervallo di date personalizzato",
    "Pick start date" : "Scegli la data di inizio",
    "Pick end date" : "Scegli la data di fine",
    "Search in date range" : "Cerca nell'intervallo di date",
    "Search in current app" : "Cerca nell'applicazione attuale",
    "Clear search" : "Svuota ricerca",
    "Search everywhere" : "Cerca ovunque",
    "Searching …" : "Ricerca in corso…",
    "Start typing to search" : "Inizia a digitare per cercare",
    "No matching results" : "Nessun risultato corrispondente",
    "Today" : "Ogg",
    "Last 7 days" : "Ultimi 7 giorni",
    "Last 30 days" : "Ultimi 30 giorni",
    "This year" : "Quest'anno",
    "Last year" : "Ultimo anno",
    "Between {startDate} and {endDate}" : "Tra {startDate} e {endDate}",
    "Unified search" : "Ricerca unificata",
    "Search apps, files, tags, messages" : "Cerca applicazioni. file, etichette, messaggi",
    "Places" : "Luoghi",
    "Date" : "Data",
    "Search people" : "Cerca le persone",
    "People" : "Persone",
    "Filter in current view" : "Filtro nella vista corrente",
    "Search connected services" : "Cerca servizi connessi",
    "Results" : "Risultati",
    "Load more results" : "Carica più risultati",
    "Search in" : "Cerca all'interno",
    "Log in" : "Accedi",
    "Logging in …" : "Accesso in corso...",
    "Log in to {productName}" : "Accedi a {productName}",
    "Wrong login or password." : "Nome utente o password errati.",
    "This account is disabled" : "Questo account è disabilitato",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Abbiamo rilevato molti tentativi di autenticazione non riusciti dal tuo indirizzo IP. Di conseguenza, il prossimo tentativo è ritardato di 30 secondi.",
    "Account name or email" : "Nome utente o email",
    "Account name" : "Nome account",
    "Server side authentication failed!" : "Autenticazione lato server non riuscita!",
    "Please contact your administrator." : "Contatta il tuo amministratore di sistema.",
    "Session error" : "Errore di sessione",
    "It appears your session token has expired, please refresh the page and try again." : "Sembra che il token di sessione sia scaduto. Aggiorna la pagina e riprova.",
    "An internal error occurred." : "Si è verificato un errore interno.",
    "Please try again or contact your administrator." : "Prova ancora o contatta il tuo amministratore.",
    "Password" : "Password",
    "Log in with a device" : "Accedi con un dispositivo",
    "Login or email" : "Nome utente o email",
    "Your account is not setup for passwordless login." : "Il tuo account non è configurato per l'accesso senza password.",
    "Your connection is not secure" : "La tua connessione non è sicura",
    "Passwordless authentication is only available over a secure connection." : "L'autenticazione senza password è disponibile solo su una connessione sicura.",
    "Browser not supported" : "Browser non supportato",
    "Passwordless authentication is not supported in your browser." : "L'autenticazione senza password non è supportata dal tuo browser. ",
    "Reset password" : "Ripristina la password",
    "Back to login" : "Torna alla schermata di accesso",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Se questo account esiste, è stato inviato un messaggio di reimpostazione della password al suo indirizzo email. Se non lo ricevi, verifica l'indirizzo di posta e/o il nome utente, controlla le cartelle spam/posta indesiderata o chiedi aiuto al tuo amministratore.",
    "Couldn't send reset email. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione. Contatta il tuo amministratore.",
    "Password cannot be changed. Please contact your administrator." : "La password non può essere cambiata. Contatta il tuo amministratore.",
    "New password" : "Nuova password",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "I tuoi file sono cifrati. Non sarà più possibile recuperare i tuoi dati una volta che la password sarà reimpostata. Se non sei sicuro, contatta l'amministratore prima di proseguire. Vuoi davvero continuare?",
    "I know what I'm doing" : "So cosa sto facendo",
    "Resetting password" : "Ripristino password",
    "Schedule work & meetings, synced with all your devices." : "Pianificare lavoro e riunioni, sincronizzati con tutti i tuoi dispositivi.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Tieni i tuoi colleghi e i tuoi amici in un posto proteggendo le loro Informazioni personali.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Applicazione di posta elettronica semplice e ben integrata con File, Contatti e Calendario.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videochiamate, condivisione dello schermo, riunioni online e web conference, direttamente dal tuo browser e dalle app mobili.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documenti collaborativi, fogli di calcolo e presentazioni, integrati in Collabora Online.",
    "Distraction free note taking app." : "Applicazione per note, senza distrazioni.",
    "Recommended apps" : "Applicazioni consigliate",
    "Loading apps …" : "Caricamento applicazioni…",
    "Could not fetch list of apps from the App Store." : "Impossibile scaricare l'elenco delle applicazioni dal negozio delle applicazioni.",
    "App download or installation failed" : "Scaricamento o installazione dell'applicazione non riuscito",
    "Cannot install this app because it is not compatible" : "Impossibile installare questa applicazione poiché non è compatibile",
    "Cannot install this app" : "Impossibile installare questa applicazione",
    "Skip" : "Salta",
    "Installing apps …" : "Installazione applicazioni…",
    "Install recommended apps" : "Installa applicazioni consigliate",
    "Avatar of {displayName}" : "Avatar di {displayName}",
    "Settings menu" : "Menu delle impostazioni",
    "Loading your contacts …" : "Caricamento dei tuoi contatti...",
    "Looking for {term} …" : "Ricerca di {term} in corso...",
    "Search contacts" : "Cerca nei contatti",
    "Reset search" : "Ripristina ricerca",
    "Search contacts …" : "Cerca contatti...",
    "Could not load your contacts" : "Impossibile caricare i tuoi contatti",
    "No contacts found" : "Nessun contatto trovato",
    "Show all contacts" : "Mostra tutti i contatti",
    "Install the Contacts app" : "Installa l'applicazione Contatti",
    "Search" : "Cerca",
    "No results for {query}" : "Nessun risultato per {query}",
    "Press Enter to start searching" : "Premi invio per iniziare la ricerca",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Digita {minSearchLength} carattere o più per cercare","Digita {minSearchLength} caratteri o più per cercare","Digita {minSearchLength} caratteri o più per cercare"],
    "An error occurred while searching for {type}" : "Si è verificato un errore durante la ricerca di {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "La ricerca inizia nel momento in cui digiti e puoi vedere i risultati con i tasti freccia",
    "Search for {name} only" : "Cerca solo {name}",
    "Loading more results …" : "Caricamento di più risultati...",
    "Forgot password?" : "Hai dimenticato la password?",
    "Back to login form" : "Torna al modulo di accesso",
    "Back" : "Indietro",
    "Login form is disabled." : "Il modulo di accesso è disabilitato.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Il modulo di accesso a Nextcloud è disabilitato. Usa un'altra opzione di accesso, se disponibile, o contatta l'amministratore.",
    "More actions" : "Altre azioni",
    "User menu" : "Menu utente",
    "Your guest name: {user}" : "Il tuo nome ospite: {user}",
    "You are currently not identified." : "Al momento non sei stato identificato.",
    "Set public name" : "Imposta nome pubblico",
    "Change public name" : "Cambia nome pubblico",
    "Password is too weak" : "La password è troppo debole",
    "Password is weak" : "La password è debole",
    "Password is average" : "La password è mediocre",
    "Password is strong" : "La password è forte",
    "Password is very strong" : "La password è molto forte",
    "Password is extremely strong" : "La password è estremamente forte",
    "Unknown password strength" : "Sicurezza della password sconosciuta",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Probabilmente la directory dei dati e i file sono accessibili da Internet perché il file <code>.htaccess</code> non funziona.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Per informazioni su come configurare correttamente il tuo server, {linkStart}consultare la documentazione{linkEnd}",
    "Autoconfig file detected" : "File di configurazione automatica rilevato",
    "The setup form below is pre-filled with the values from the config file." : "Il modulo di configurazione riportato di seguito è precompilato con i valori del file di configurazione.",
    "Security warning" : "Avviso di sicurezza",
    "Create administration account" : "Crea un account amministrazione",
    "Administration account name" : "Nome dell'account di amministrazione",
    "Administration account password" : "Password dell'account di amministrazione",
    "Storage & database" : "Archiviazione e database",
    "Data folder" : "Cartella dati",
    "Database configuration" : "Configurazione del database",
    "Only {firstAndOnlyDatabase} is available." : "Solo {firstAndOnlyDatabase} è disponibile.",
    "Install and activate additional PHP modules to choose other database types." : "Installa e attiva i moduli PHP aggiuntivi per scegliere gli altri tipi di database.",
    "For more details check out the documentation." : "Per ulteriori dettagli, leggi la documentazione.",
    "Performance warning" : "Avviso di prestazioni",
    "You chose SQLite as database." : "Hai scelto SQLite come database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite dovrebbe essere scelto solo per istanze minimali e di sviluppo. Per la produzione, consigliamo un motore di database diverso.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utilizzi client per la sincronizzazione dei file, l'uso di SQLite è sconsigliato.",
    "Database user" : "Utente del database",
    "Database password" : "Password del database",
    "Database name" : "Nome del database",
    "Database tablespace" : "Spazio delle tabelle del database",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifica il numero della porta insieme al nome host (ad es. localhost:5432).",
    "Database host" : "Host del database",
    "localhost" : "localhost",
    "Installing …" : "Installazione …",
    "Install" : "Installa",
    "Need help?" : "Ti serve aiuto?",
    "See the documentation" : "Leggi la documentazione",
    "{name} version {version} and above" : "{name} versione {version} e successive",
    "This browser is not supported" : "Questo browser non è supportato",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Il tuo browser non è supportato. Effettua l'aggiornamento a una versione più recente o supportata.",
    "Continue with this unsupported browser" : "Prosegui con questo browser non supportato",
    "Supported versions" : "Versioni supportate",
    "Search {types} …" : "Cerca {types}...",
    "Choose {file}" : "Scegli {file}",
    "Choose" : "Scegli",
    "Copy to {target}" : "Copia in {target}",
    "Copy" : "Copia",
    "Move to {target}" : "Sposta in {target}",
    "Move" : "Sposta",
    "OK" : "OK",
    "read-only" : "sola lettura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} file in conflitto","{count} file in conflitto","{count} file in conflitto"],
    "One file conflict" : "Un file in conflitto",
    "New Files" : "File nuovi",
    "Already existing files" : "File già esistenti",
    "Which files do you want to keep?" : "Quali file vuoi mantenere?",
    "If you select both versions, the copied file will have a number added to its name." : "Se selezioni entrambe le versioni, sarà aggiunto un numero al nome del file copiato.",
    "Cancel" : "Annulla",
    "Continue" : "Continua",
    "(all selected)" : "(tutti i selezionati)",
    "({count} selected)" : "({count} selezionati)",
    "Error loading file exists template" : "Errore durante il caricamento del modello del file esistente",
    "Saving …" : "Salvataggio…",
    "seconds ago" : "secondi fa",
    "Connection to server lost" : "Connessione al server interrotta",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema durante il caricamento della pagina, aggiornamento tra %n secondo","Problema durante il caricamento della pagina, aggiornamento tra %n secondi","Problema durante il caricamento della pagina, aggiornamento tra %n secondi"],
    "Add to a project" : "Aggiungi a un progetto",
    "Show details" : "Mostra dettagli",
    "Hide details" : "Nascondi dettagli",
    "Rename project" : "Rinomina progetto",
    "Failed to rename the project" : "Rinomina progetto non riuscita",
    "Failed to create a project" : "Creazione progetto non riuscita",
    "Failed to add the item to the project" : "Aggiunta dell'elemento al progetto non riuscita",
    "Connect items to a project to make them easier to find" : "Collega elementi a un progetto per poterli trovare più facilmente",
    "Type to search for existing projects" : "Digita per cercare progetti esistenti",
    "New in" : "Nuovo in",
    "View changelog" : "Visualizza le novità",
    "No action available" : "Nessuna azione disponibile",
    "Error fetching contact actions" : "Errore durante il recupero delle azioni dei contatti",
    "Close \"{dialogTitle}\" dialog" : "Chiudi la finestra \"{dialogTitle}\"",
    "Email length is at max (255)" : "La lunghezza dell'email è al massimo (255)",
    "Non-existing tag #{tag}" : "Etichetta #{tag} inesistente",
    "Restricted" : "Limitato",
    "Invisible" : "Invisibile",
    "Delete" : "Elimina",
    "Rename" : "Rinomina",
    "Collaborative tags" : "Etichette collaborative",
    "No tags found" : "Nessuna etichetta trovata",
    "Clipboard not available, please copy manually" : "Appunti non disponibili, copiare manualmente",
    "Personal" : "Personale",
    "Accounts" : "Account",
    "Admin" : "Admin",
    "Help" : "Aiuto",
    "Access forbidden" : "Accesso negato",
    "You are not allowed to access this page." : "Non ti è consentito accedere a questa pagina.",
    "Back to %s" : "Torna a %s",
    "Page not found" : "Pagina non trovata",
    "The page could not be found on the server or you may not be allowed to view it." : "La pagina non è stata trovata sul server o forse non ti è permesso vederla.",
    "Too many requests" : "Troppe richieste",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Sono arrivate troppe richieste dalla tua rete. Riprova più tardi o contatta il tuo amministratore se questo è un errore.",
    "Error" : "Errore",
    "Internal Server Error" : "Errore interno del server",
    "The server was unable to complete your request." : "Il server non è stato in grado di completare la tua richiesta.",
    "If this happens again, please send the technical details below to the server administrator." : "Se ciò si verifca nuovamente, invia i seguenti dettagli tecnici all'amministratore del server.",
    "More details can be found in the server log." : "Ulteriori dettagli sono disponibili nel log del server.",
    "For more details see the documentation ↗." : "Per ulteriori dettagli, leggi la documentazione ↗.",
    "Technical details" : "Dettagli tecnici",
    "Remote Address: %s" : "Indirizzo remoto: %s",
    "Request ID: %s" : "ID richiesta: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Codice: %s",
    "Message: %s" : "Messaggio: %s",
    "File: %s" : "File: %s",
    "Line: %s" : "Riga: %s",
    "Trace" : "Traccia",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembra che tu stia tentando di reinstallare il tuo Nextcloud. Tuttavia, manca il file CAN_INSTALL dalla cartella config. Crea il file CAN_INSTALL nella cartella config per continuare.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Impossibile rimuovere il file CAN_INSTALL dalla cartella config. Rimuovi il file manualmente.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Questa applicazione richiede JavaScript per un corretto funzionamento. {linkstart}Abilita JavaScript{linkend} e ricarica la pagina.",
    "Skip to main content" : "Passa al contenuto principale",
    "Skip to navigation of app" : "Passa alla navigazione dell'applicazione",
    "Go to %s" : "Vai a %s",
    "Get your own free account" : "Ottieni il tuo account gratuito",
    "Connect to your account" : "Connetti il tuo account",
    "Please log in before granting %1$s access to your %2$s account." : "Accedi prima di accordare a %1$s l'accesso al tuo account %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se non stai tentando di configurare un nuovo dispositivo o applicazione, qualcuno sta provando a ingannarti per ottenere l'accesso ai tuoi dati. In questo caso non procedere e contatta l'amministratore di sistema.",
    "App password" : "Password dell'applicazione",
    "Grant access" : "Accorda accesso",
    "Alternative log in using app password" : "Accesso alternativo utilizzando la password dell'applicazione",
    "Account access" : "Accesso account",
    "Currently logged in as %1$s (%2$s)." : "Attualmente connesso come %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Stai per accordare a %1$s l'accesso al tuo account %2$s.",
    "Account connected" : "Account connesso",
    "Your client should now be connected!" : "Il client ora dovrebbe essere connesso!",
    "You can close this window." : "Puoi chiudere questa finestra.",
    "Previous" : "Precedente",
    "This share is password-protected" : "Questa condivisione è protetta da password",
    "The password is wrong or expired. Please try again or request a new one." : "La password è errata o scaduta. Riprova o richiedine una nuova.",
    "Please type in your email address to request a temporary password" : "Inserisci il tuo indirizzo email per richiedere una password temporanea",
    "Email address" : "Indirizzo email",
    "Password sent!" : "Password inviata!",
    "You are not authorized to request a password for this share" : "Non sei autorizzato a richiedere una password per questa condivisione",
    "Two-factor authentication" : "Autenticazione a due fattori",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La sicurezza migliorata è abilitata per il tuo account. Scegli un secondo fattore per l'autenticazione:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Impossibile caricare almeno uno dei metodi di autenticazione a due fattori. Contatta il tuo amministratore.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "L'autenticazione a due fattori è applicata, ma non è stata configurata nel tuo account. Contatta il tuo amministratore per assistenza.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "L'autenticazione a due fattori è applicata, ma non è stata configurata nel tuo account. Continua per configurare l'autenticazione a due fattori.",
    "Set up two-factor authentication" : "Configura l'autenticazione a due fattori",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "L'autenticazione a due fattori è applicata, ma non è stata configurata nel tuo account. Utilizza uno dei tuoi codici di backup per accedere o contatta il tuo amministratore per assistenza.",
    "Use backup code" : "Usa il codice di backup",
    "Cancel login" : "Annulla l'accesso",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "La sicurezza migliorata è applicata al tuo account. Scegli quale fornitore configurare:",
    "Error while validating your second factor" : "Errore durante la convalida del tuo secondo fattore",
    "Access through untrusted domain" : "Accedi tramite un dominio non attendibile",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contatta il tuo amministratore. Se sei un amministratore, modifica l'impostazione \"trusted_domains\" in config/config.php come l'esempio disponibile in config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ulteriori informazioni sulla configurazione sono disponibili nella %1$s documentazione %2$s.",
    "App update required" : "Aggiornamento dell'applicazione richiesto",
    "%1$s will be updated to version %2$s" : "%1$s sarà aggiornato alla versione %2$s",
    "The following apps will be updated:" : "Le seguenti applicazioni saranno aggiornate:",
    "These incompatible apps will be disabled:" : "Queste applicazioni incompatibili saranno disabilitate:",
    "The theme %s has been disabled." : "Il tema %s è stato disabilitato.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assicurati di aver creato una copia di sicurezza del database, della cartella config e della cartella data prima di procedere. ",
    "Start update" : "Avvia l'aggiornamento",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitare timeout con installazioni di grandi dimensioni, puoi eseguire il comando che segue dalla cartella di installazione:",
    "Detailed logs" : "Log dettagliati",
    "Update needed" : "Aggiornamento necessario",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Utilizza lo strumento di aggiornamento tramite riga di comando in quanto disponi di un'istanza di grandi dimensioni con più di 50 utenti.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per la guida, vedi la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentazione</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sono consapevole che, procedendo con l'aggiornamento tramite interfaccia web, esista il rischio che la richiesta possa scadere e causare perdite di dati, ma ho una copia di sicurezza e so come ripristinare la mia istanza in caso di problemi.",
    "Upgrade via web on my own risk" : "Aggiorna tramite web a mio rischio",
    "Maintenance mode" : "Modalità Manutenzione",
    "This %s instance is currently in maintenance mode, which may take a while." : "Questa istanza di %s è attualmente in manutenzione, potrebbe richiedere del tempo.",
    "This page will refresh itself when the instance is available again." : "Questa pagina si aggiornerà quando l'istanza sarà nuovamente disponibile.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contatta il tuo amministratore di sistema se questo messaggio persiste o appare inaspettatamente.",
    "Error occurred while checking server setup" : "Si è verificato un errore durante il controllo della configurazione del server",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Per ulteriori dettagli, leggi la {linkstart}documentazione ↗{linkend}.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videochiamate, condivisione schermo, riunioni in linea e conferenze web – nel tuo browser e con le applicazioni mobili.",
    "You have not added any info yet" : "Non hai ancora aggiunto alcuna informazione",
    "{user} has not added any info yet" : "{user} non ha ancora aggiunto alcuna informazione",
    "Error opening the user status modal, try hard refreshing the page" : "Errore nell'apertura dello stato utente, prova a ricaricare la pagina",
    "Edit Profile" : "Modifica il profilo",
    "The headline and about sections will show up here" : "Le sezioni del titolo e delle informazioni verranno mostrate qui",
    "Very weak password" : "Password molto debole",
    "Weak password" : "Password debole",
    "So-so password" : "Password così-così",
    "Good password" : "Password buona",
    "Strong password" : "Password forte",
    "Profile not found" : "Profilo non trovato",
    "The profile does not exist." : "Il profilo non esiste.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La cartella dei dati e i file sono probabilmente accessibili da Internet poiché il file .htaccess non funziona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per informazioni su come configurare correttamente il tuo server, vedi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentazione</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Crea un account amministratore</strong>",
    "New admin account name" : "Nuovo nome account amministratore",
    "New admin password" : "Nuova password amministratore",
    "Show password" : "Mostra password",
    "Toggle password visibility" : "Commuta la visibilità delle password",
    "Configure the database" : "Configura il database",
    "Only %s is available." : "È disponibile solo %s.",
    "Database account" : "Database account",
    "Direct link copied to clipboard" : "Collegamento diretto copiato negli appunti"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
